@@ -14,29 +14,33 @@ A light, file based batch system.
 
 =head3 a short example
 
-=begin verbatim
 
 #edit examples/sbsconfig-examples-1.xml to put your own local machines (it can be a good idea, if you have not a cluster, to enter your local machine with different addresses (localhost, 123.156.78.90, hostname) to see sommething a bit more realistic...
 
 #System status
 #in a side term, to see every second the 
-watch -n 1 ../scripts/scheduler-print.pl --config=sbsconfig-examples-1.xml
+watch -n 1 ../scripts/sbs-scheduler-print.pl --config=sbsconfig-examples-1.xml
 
 #to submit or dozen or so scripts on queue 'single'
-../scripts/batch-submit.pl --config=sbsconfig-examples-1.xml  --queue=single --command=a.sh  --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh  --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh
+
+../scripts/sbs-batch-submit.pl --config=sbsconfig-examples-1.xml  --queue=single --command=a.sh  --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh  --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh
+
 #and on a higher priority queue
-../scripts/batch-submit.pl --config=sbsconfig-examples-1.xml  --queue=single_high --command=a.sh  --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh  --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh
+
+../scripts/sbs-batch-submit.pl --config=sbsconfig-examples-1.xml  --queue=single_high --command=a.sh  --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh  --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh --command=a.sh
 
 #to update
-../scripts/scheduler-update.pl --config=sbsconfig-examples-1.xml
+
+../scripts/sbs-scheduler-update.pl --config=sbsconfig-examples-1.xml
 
 #to check data consistency (and solve main problems
-../scripts/scheduler-check.pl
+
+../scripts/sbs-scheduler-check.pl
 
 #to remove a job --config=sbsconfig-examples-1.xml
-../scripts/batch-remove  --config=sbsconfig-examples-1.xml yourjobid
 
-=end verbatim
+../scripts/sbs-batch-remove  --config=sbsconfig-examples-1.xml yourjobid
+
 
 =head3 submiting command
 
@@ -169,7 +173,7 @@ use BatchSystem::SBS::Common qw(lockFile unlockFile);
   use Object::InsideOut 'Exporter';
 
   BEGIN{
-    our $VERSION = '0.01';
+    our $VERSION = '0.03';
     our @EXPORT = qw( &getUserList &getCGIUser );
     our @EXPORT_OK = ();
   }
@@ -207,7 +211,8 @@ use BatchSystem::SBS::Common qw(lockFile unlockFile);
     $self->scheduler->job_submit(id=>$jid,
 				 queue=>$queue,
 				 dir=>$dir,
-				 command=>$cmd
+				 command=>$cmd,
+				 on_finished=>$hprms{on_finished},
 				);
     return $jid;
   }
